@@ -9,6 +9,7 @@ from markdown.extensions import Extension
 import yaml
 import json
 import re
+import uuid
 
 
 def labelValue(out, content, label):
@@ -88,6 +89,9 @@ class SwaggerDefinition():
         
 
     def definitionTable(self, definition, defname):
+        if not definition.get('properties'):
+            return self.simpleDefinition(definition, defname)
+
         body = []
         required = definition.get('required', [])
         properties = definition.get('properties', {})
@@ -97,6 +101,17 @@ class SwaggerDefinition():
             self.addTableLine([defname], body, name, content, required)
         return self.table(body=''.join(body), id=defname)
 
+    def simpleDefinition(self, definition, defname):
+        details = self.details(definition, defname)
+        ctype = self.typeAndFormat(definition)
+        body = f"""<tr><td>{defname}</td><td>{ctype}</td><td>{details}</td></tr>"""
+
+        return f"""<table data-type="sw-table" id="/definitions/{defname}"> 
+        <thead><tr><th>Name</th><th>Type</th><th>Details</th></tr></thead>
+        <tbody>{body}</tbody>
+        </table>
+        """
+
     def details(self, content, name):
         out = []
         keys = content.keys()
@@ -465,6 +480,9 @@ Request code example
             return self.getRandomValue(content)
 
     def getRandomValue(self, content):
+        schema = content.get('schema')
+        if schema:
+            content = schema
         ctype = content.get('type')
         format = content.get('format')
         example = content.get('example')
@@ -483,6 +501,10 @@ Request code example
                 return '2017-07-21T17:32:28Z'
             if format == 'password':
                 return '*****'
+            if format == 'email':
+                return 'example@example.com'
+            if format == 'uuid':
+                return str(uuid.uuid4())
             return 'lorem ipsum'
         elif ctype == 'boolean':
             return True
